pub struct NodeContact { /* private fields */ }Expand description
This type relaxes the requirement of having an ENR to connect to a node, to allow for unsigned connection types, such as multiaddrs.
Implementations
Sourceimpl NodeContact
impl NodeContact
pub fn new( public_key: CombinedPublicKey, socket_addr: SocketAddr, enr: Option<Enr>, ) -> Self
pub fn node_id(&self) -> NodeId
pub fn seq_no(&self) -> Option<u64>
pub fn public_key(&self) -> CombinedPublicKey
pub fn enr(&self) -> Option<Enr>
pub fn socket_addr(&self) -> SocketAddr
pub fn node_address(&self) -> NodeAddress
pub fn to_address_and_enr(self) -> (NodeAddress, Option<Enr>)
pub fn try_from_enr(enr: Enr, ip_mode: IpMode) -> Result<Self, NonContactable>